
#ifndef DEFAULT_ALIGN
#define DEFAULT_ALIGN 50	/* default alignment column for results */
#endif				/* (-a switch) */

#ifndef MAX_ARGS
#define MAX_ARGS        32	/* maximum number of args for a function */
#endif

#ifndef DEFAULT_STRLEN
#define DEFAULT_STRLEN  32	/* default maximum # of bytes printed in */
#endif				/* strings (-s switch) */

#ifndef DEFAULT_ARRAYLEN
#define DEFAULT_ARRAYLEN  4	/* default maximum # array elements */
#endif				/* (-A switch) */

#define MAX_LIBRARIES 30
